==> phplist-2.10.5p0.tgz: lists/admin/help/es/format.php <==
<h3>Formato del mensaje</h3>
Si utiliza &#171;Auto detectar&#187; el mensaje ser&aacute; considerado HTML en cuanto se encuentre la primera etiqueta HTML (&lt; ... &gt;).
</p><p><b>No hay problema en dejar seleccionado &#171;Auto detectar&#187;.</b></p><p>
Si no est&aacute; seguro de si &#171;Auto detectar&#187; funciona, y el mensaje que est&aacute; pegando ha sido formateado en HTML, escoja &#171;HTML&#187;.
Referencias a recursos externos (p. ej. im&aacute;genes) requieren la URL completa, es decir incluyendo el &#171;http://&#187; (al contrario que las im&aacute;gines de los patrones).
En todo lo dem&aacute;s, el formato del texto depende enteramente de usted.
<p>Si quiere que el mensaje se env&iacute;e a todos en texto plano, seleccione &#171;Texto&#187;.
</p><p>
Esta informaci&oacute;n se usa para crear la versi&oacute;n en texto plano de un correo HTML, o la versi&oacute;n HTML de un mensaje en texto plano.
El formateado ser&aacute; as&iacute;:<br/>
El original es HTML -&gt; texto plano<br/>
<ul>
<li>El texto en <b>negritas</b> aparecer&aacute; enmarcado por <b>*-asteriscos</b>, el texto en <b>cursiva</b> por <b>/-barras</b>.</li>
<li>Los enlaces ser&aacute;n sustitu&iacute;dos por el texto del enlace, seguido por la URL entre par&eacute;ntesis.</li>
<li>Los fragmentos de texto largos quedar&aacute;n divididos en l&iacute;neas de un m&aacute;ximo de 70 caracteres, sin dividir palabras.</li>
</ul>
El original es Texto -&gt; HTML<br/>
<ul>
<li>Dos saltos de l&iacute;nea seguidos ser&aacute;n sustitu&iacute;dos por &lt;p&gt; (p&aacute;rrafo)</li>
<li>Un s&oacute;lo salto de l&iacute;nea ser&aacute; sustitu&iacute;do por &lt;br /&gt; (salto de l&iacute;nea)</li>
<li>Se podr&aacute; pinchar en las direcciones de correo electr&oacute;nico</li>
<li>Se podr&aacute; pinchar en las URL. Estas pueden tener los siguientes formatos:<br/>
<ul><li>http://cierta.p&aacute;gina.url/cierta/direcci&oacute;n/fichero.html
<li>www.urlsitioweb.com
</ul>
Los enlaces creados tendr&aacute;n, con respecto a la hoja de estilo, <i>class</i> &#171;url&#187; y <i>target</i> &#171;_blank&#187;.
</ul>
<b>Advertencia</b>: Si indica que su mensaje es texto plano, pero pega un texto HTML en el formulario, los usuarios que han escogido recibir mensajes en texto plano recibir&aacute;n el mensaje con las etiquetas HTML visibles.

==> phplist-2.10.14p1.tgz: lists/admin/help/es/format.php <==
<h3>Formato del mensaje</h3>
Si utiliza &#171;Auto detectar&#187; el mensaje ser&aacute; considerado HTML en cuanto se encuentre la primera etiqueta HTML (&lt; ... &gt;).
</p><p><b>No hay problema en dejar seleccionado &#171;Auto detectar&#187;.</b></p><p>
Si no est&aacute; seguro de si &#171;Auto detectar&#187; funciona, y el mensaje que est&aacute; pegando ha sido formateado en HTML, escoja &#171;HTML&#187;.
Referencias a recursos externos (p. ej. im&aacute;genes) requieren la URL completa, es decir incluyendo el &#171;http://&#187; (al contrario que las im&aacute;gines de las plantillas).
En todo lo dem&aacute;s, el formato del texto depende enteramente de usted.
<p>Si quiere que el mensaje se env&iacute;e a todos en texto plano, seleccione &#171;Texto&#187;.
</p><p>
Esta informaci&oacute;n se usa para crear la versi&oacute;n en texto plano de un correo HTML, o la versi&oacute;n HTML de un mensaje en texto plano.
El formateado ser&aacute; as&iacute;:<br/>
El original es HTML -&gt; texto plano<br/>
<ul>
<li>El texto en <b>negritas</b> aparecer&aacute; enmarcado por <b>*-asteriscos</b>, el texto en <b>cursiva</b> por <b>/-barras</b>.</li>
<li>Los enlaces ser&aacute;n sustitu&iacute;dos por el texto del enlace, seguido por la URL entre par&eacute;ntesis.</li>
<li>Los fragmentos de texto largos quedar&aacute;n divididos en l&iacute;neas de un m&aacute;ximo de 70 caracteres, sin dividir palabras.</li>
</ul>
El original es Texto -&gt; HTML<br/>
<ul>
<li>Dos saltos de l&iacute;nea seguidos ser&aacute;n sustitu&iacute;dos por &lt;p&gt; (p&aacute;rrafo)</li>
<li>Un s&oacute;lo salto de l&iacute;nea ser&aacute; sustitu&iacute;do por &lt;br /&gt; (salto de l&iacute;nea)</li>
<li>Se podr&aacute; pinchar en las direcciones de correo electr&oacute;nico</li>
<li>Se podr&aacute; pinchar en las URL. Estas pueden tener los siguientes formatos:<br/>
<ul><li>http://cierta.p&aacute;gina.url/cierta/direcci&oacute;n/fichero.html
<li>www.urlsitioweb.com
</ul>
Los enlaces creados tendr&aacute;n, con respecto a la hoja de estilo, <i>class</i> &#171;url&#187; y <i>target</i> &#171;_blank&#187;.
</ul>
<b>Advertencia</b>: Si indica que su mensaje es texto plano, pero pega un texto HTML en el formulario, los usuarios que han escogido recibir mensajes en texto plano recibir&aacute;n el mensaje con las etiquetas HTML visibles.
